==> haskell-swagger2-2.8.9-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 swagger2
version:              2.8.9
visibility:           public
id:                   swagger2-2.8.9-DaUbPLGt9bQGGVh6Fl33YJ
key:                  swagger2-2.8.9-DaUbPLGt9bQGGVh6Fl33YJ
license:              BSD-3-Clause
copyright:            (c) 2015-2016, GetShopTV
maintainer:           nickolay@getshoptv.com
author:               Nickolay Kudasov
homepage:             https://github.com/GetShopTV/swagger2
synopsis:             Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.

    The original Swagger 2.0 specification is available at http://swagger.io/specification/.

category:             Web, Swagger
abi:                  7d9fba97dca6b02835d3290b20dfa137
exposed:              True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.Optics
    Data.Swagger.ParamSchema Data.Swagger.Schema
    Data.Swagger.Schema.Generator Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions

import-dirs:          /usr/lib/ghc-9.2.8/site-local/swagger2-2.8.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/swagger2-2.8.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-swagger2
hs-libraries:         HSswagger2-2.8.9-DaUbPLGt9bQGGVh6Fl33YJ
depends:
    QuickCheck-2.14.3-DB9X9Jr9tgaB7YjSEeodGO
    aeson-2.1.2.1-8ueLuG1qYj9Fbt4mgkSEM3
    aeson-pretty-0.8.10-JsgAmdnqgLWA0FLX94mGl4 base-4.16.4.0
    base-compat-batteries-0.12.2-2JTOyflgK69BsE8z9vF9ez
    bytestring-0.11.4.0 containers-0.6.5.1
    cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5
    generics-sop-0.5.1.3-4YBaeXZJxE773SDkSmYv25
    hashable-1.4.4.0-JPPoH0HitSIaCdulNsJk5
    http-media-0.8.1.1-GSdhjXs6mh5JYfNOUMvmy7
    insert-ordered-containers-0.2.5.3-K046NOhYvTYH23NVb3pTm6
    lens-5.2.3-IfVI0lYg8YCKwUpCShTCzd mtl-2.2.2
    network-3.1.4.0-LhtvsRHDdQTLLUvoMZ3hgi
    optics-core-0.4.1.1-7O8NOYAlIoD4g8uxSGsg7O
    optics-th-0.4.1-FOYSc1nBj27GQirPHPvvET
    scientific-0.3.7.0-5LYId1uMyYd6WtLuciLYcq template-haskell-2.18.0.0
    text-1.2.5.0 time-1.11.1.1 transformers-0.5.6.2
    unordered-containers-0.2.20-E4Tm9IvXwjlGK4H2DBnoSH
    uuid-types-1.0.5.1-LfdQaQtimrF27WwXkBX9iU
    vector-0.13.1.0-IsxGr1wjc8yHuZdiqe6rZF

haddock-interfaces:   /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html:         /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-swagger2-2.8.9-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 swagger2
version:              2.8.9
visibility:           public
id:                   swagger2-2.8.9-HcYudZY9l9rAV8kGxVIA7X
key:                  swagger2-2.8.9-HcYudZY9l9rAV8kGxVIA7X
license:              BSD-3-Clause
copyright:            (c) 2015-2016, GetShopTV
maintainer:           nickolay@getshoptv.com
author:               Nickolay Kudasov
homepage:             https://github.com/GetShopTV/swagger2
synopsis:             Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.

    The original Swagger 2.0 specification is available at http://swagger.io/specification/.

category:             Web, Swagger
abi:                  9014748d3f7933ef5244f2c3b4124531
exposed:              True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.Optics
    Data.Swagger.ParamSchema Data.Swagger.Schema
    Data.Swagger.Schema.Generator Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions

import-dirs:          /usr/lib/ghc-9.2.8/site-local/swagger2-2.8.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/swagger2-2.8.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-swagger2
hs-libraries:         HSswagger2-2.8.9-HcYudZY9l9rAV8kGxVIA7X
depends:
    QuickCheck-2.14.3-1sWCe8KuaHp2ZxS22lbvKK
    aeson-2.1.2.1-3lugcDour1r4V4jv6ZKvkq
    aeson-pretty-0.8.10-krcHlNXHmUAtULuMyAemH base-4.16.4.0
    base-compat-batteries-0.12.2-4MEyHsIGw4qJXDmutpY0Yq
    bytestring-0.11.4.0 containers-0.6.5.1
    cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5
    generics-sop-0.5.1.3-4YBaeXZJxE773SDkSmYv25
    hashable-1.4.4.0-CxCIesSa4aLFiFeBLAsQal
    http-media-0.8.1.1-LIh7ToSvuZq9hv5XPa46uR
    insert-ordered-containers-0.2.5.3-B3ipyDHJsKP1q4sIIh6trk
    lens-5.2.3-LJCKq2CVV0OBzhsqfjAjcB mtl-2.2.2
    network-3.1.4.0-FV8xnMEmZuK2exBKJ6b61i
    optics-core-0.4.1.1-C8qbbvdZcoc49gWfNkDlAM
    optics-th-0.4.1-EyGrcNscUUdAaGIPWSA40I
    scientific-0.3.7.0-7p41gUaaSP7BrDOTk8p39O template-haskell-2.18.0.0
    text-1.2.5.0 time-1.11.1.1 transformers-0.5.6.2
    unordered-containers-0.2.20-2iyjFoh2jxC3XOaFpxfD6Q
    uuid-types-1.0.5.1-5XVSegQhTJxLWMhfB0jOyk
    vector-0.13.1.0-HRMJcTNtHmH9PMIsGjP73X

haddock-interfaces:   /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html:         /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
